@@ -112,7 +112,7 @@ def run_tests(test_path, path_type='file'):
 
 def install_requirements(req_file):
     logging.info(f"Install python requirement file {req_file}")
-    c = ["pip", "install", "--quiet", "-r", req_file]
+    c = ["pip", "install", "-r", req_file]
     subprocess.check_call(c)
 
 
